
clear all

fpath = '..\runs\Case4\Roller\';
fpathnr = '..\runs\Case4\NoRoller\';

%measured
zm = load('..\data\Visser_Case4_Setup.txt');
um = load('..\data\Visser_Case4_Current.txt');
hm = load('..\data\Visser_Case4_Wave.txt');

%Grid
info = hdf5info([fpath,'Flow_V4_grid.h5']);
s = info.GroupHierarchy.Groups;
nx = s.Attributes(7).Value;
ny = s.Attributes(8).Value;
x = hdf5read(s.Datasets(1));
x = 14.15-x;

ind = 20;
%------ Roller --------------------
sol = readcmsh5([fpath,'Flow_V4_sol.h5']);
%Water elevation
eta = reshape(sol.Water_Elevation.Values(:,end),[nx,ny]);
eta = eta(:,ind);

%Current velocity
u = reshape(sol.Current_Magnitude.Values(:,end),[nx,ny]);
u = u(:,ind);

%Wave height
H = reshape(sol.Wave_Height.Values(:,end),[nx,ny]);
H = H(:,ind)/sqrt(2);
H(H<0) = NaN;

%---- No Roller ------------------
sol = readcmsh5([fpathnr,'Flow_V4_sol.h5']);
%Water elevation
eta2 = reshape(sol.Water_Elevation.Values(:,end),[nx,ny]);
eta2 = eta2(:,ind);

%Current velocity
u2 = reshape(sol.Current_Magnitude.Values(:,end),[nx,ny]);
u2 = u2(:,ind);

%Wave height
H2 = reshape(sol.Wave_Height.Values(:,end),[nx,ny]);
H2 = H2(:,ind)/sqrt(2);
H2(H2<0) = NaN;

%---- Plotting --------------
h = figure('position',[423   116   421   484]);
subplot(3,1,1)
%plot(x,H,'k-',hm(:,1),hm(:,2),'ok','Markerfacecolor','k')
plot(x,H,'b-',x,H2,'r--',hm(:,1),hm(:,2),'ok','Markerfacecolor','k','linewidth',2)
set(gca,'xlim',[0,6],'ylim',[0 0.1])
ylabel('Wave Height, m')
title('Visser Case 4')

subplot(3,1,2)
%plot(x,u,'k-',um(:,1),um(:,2),'^k','Markerfacecolor','k')
plot(x,u,'b-',x,u2,'r--',um(:,1),um(:,2),'ok','Markerfacecolor','k','linewidth',2)
set(gca,'xlim',[0,6],'ylim',[0 0.5])
ylabel('Current Velocity, m/s')

subplot(3,1,3)
%plot(x,eta,'k-',zm(:,1),zm(:,2),'sk','Markerfacecolor','k')
plot(x,eta,'b-',x,eta2,'r--',zm(:,1),zm(:,2),'ok','Markerfacecolor','k','linewidth',2)
set(gca,'xlim',[0,6],'ylim',[-0.005 0.02])
ylabel('Water Level, m')
xlabel('Distance, m')

legend('Roller','No Roller','Measured')

% saveas(h,'..\images\Visser4.tif') 
% set(h,'PaperPositionMode','auto')
% saveas(h,'..\images\Visser4.png') 

%--- Goodness of fit statistics ----
rmse = zeros(3,2);
nrmse = zeros(3,2);
nmae = zeros(3,2);
R2 = zeros(3,2);
bias = zeros(3,2);

%Wave height
ind = isfinite(H);
yc = interp1(x(ind),H(ind),hm(:,1));
ym = hm(:,2);
% figure, plot(yc,ym,'.',[0,0.1],[0,0.1],'k')
rmse(1,1) = sqrt(mean((yc-ym).^2));
nrmse(1,1) = sqrt(mean((yc-ym).^2))/max(ym);
nmae(1,1) = mean(abs((yc-ym)))/max(ym); 
R = corrcoef(yc,ym);
R2(1,1) = R(1,2)^2;
bias(1,1) = mean(yc-ym);

ind = isfinite(H2);
yc = interp1(x(ind),H2(ind),hm(:,1));
ym = hm(:,2);
% figure, plot(yc,ym,'.',[0,0.1],[0,0.1],'k')
rmse(1,2) = sqrt(mean((yc-ym).^2));
nrmse(1,2) = sqrt(mean((yc-ym).^2))/max(ym);
nmae(1,2) = mean(abs((yc-ym)))/max(ym); 
R = corrcoef(yc,ym);
R2(1,2) = R(1,2)^2;
bias(1,2) = mean(yc-ym);

%Current velocity
ind = isfinite(u);
yc = interp1(x(ind),u(ind),um(:,1));
ym = um(:,2);
% figure, plot(yc,ym,'.',[0,0.1],[0,0.1],'k')
rmse(2,1) = sqrt(mean((yc-ym).^2));
nrmse(2,1) = sqrt(mean((yc-ym).^2))/max(ym);
nmae(2,1) = mean(abs((yc-ym)))/max(ym); 
R = corrcoef(yc,ym);
R2(2,1) = R(1,2)^2;
bias(2,1) = mean(yc-ym);

ind = isfinite(u2);
yc = interp1(x(ind),u2(ind),um(:,1));
ym = um(:,2);
% figure, plot(yc,ym,'.',[0,0.1],[0,0.1],'k')
rmse(2,2) = sqrt(mean((yc-ym).^2));
nrmse(2,2) = sqrt(mean((yc-ym).^2))/max(ym);
nmae(2,2) = mean(abs((yc-ym)))/max(ym); %Note offshore wave height used
R = corrcoef(yc,ym);
R2(2,2) = R(1,2)^2;
bias(2,2) = mean(yc-ym);

%Water elevation
ind = isfinite(eta);
yc = interp1(x(ind),eta(ind),zm(:,1));
ym = zm(:,2);
% figure, plot(yc,ym,'.',[0,0.1],[0,0.1],'k')
rmse(3,1) = sqrt(mean((yc-ym).^2));
nrmse(3,1) = sqrt(mean((yc-ym).^2))/(max(ym)-min(ym));
nmae(3,1) = mean(abs((yc-ym)))/(max(ym)-min(ym)); %Note offshore wave height used
R = corrcoef(yc,ym);
R2(3,1) = R(1,2)^2;
bias(3,1) = mean(yc-ym);

ind = isfinite(eta2);
yc = interp1(x(ind),eta2(ind),zm(:,1));
ym = zm(:,2);
% figure, plot(yc,ym,'.',[0,0.1],[0,0.1],'k')
rmse(3,2) = sqrt(mean((yc-ym).^2));
nrmse(3,2) = sqrt(mean((yc-ym).^2))/(max(ym)-min(ym));
nmae(3,2) = mean(abs((yc-ym)))/(max(ym)-min(ym)); %Note offshore wave height used
R = corrcoef(yc,ym);
R2(3,2) = R(1,2)^2;
bias(3,2) = mean(yc-ym);

disp('--- Visser Case 4 goodness of fit statistics ---')
disp('Variable                 NRMSE    NMAE    R^2   Bias')
disp('- No Roller -')
fprintf(1,'%s %14.4f,%7.4f,%6.3f,%6.3f\n','Wave height (m)',[nrmse(1,2),nmae(1,2),R2(1,2),bias(1,2)]);
fprintf(1,'%s %7.4f,%7.4f,%6.3f,%6.3f\n','Current velocity (m/s)',[nrmse(2,2),nmae(2,2),R2(2,2),bias(2,2)]);
fprintf(1,'%s %14.4f,%7.4f,%6.3f,%6.3f\n','Water level (m)',[nrmse(3,2),nmae(3,2),R2(3,2),bias(3,2)]);
disp('- Roller -')
fprintf(1,'%s %14.4f,%7.4f,%6.3f,%6.3f\n','Wave height (m)',[nrmse(1,1),nmae(1,1),R2(1,1),bias(1,1)]);
fprintf(1,'%s %7.4f,%7.4f,%6.3f,%6.3f\n','Current velocity (m/s)',[nrmse(2,1),nmae(2,1),R2(2,1),bias(2,1)]);
fprintf(1,'%s %14.4f,%7.4f,%6.3f,%6.3f\n','Water level (m)',[nrmse(3,1),nmae(3,1),R2(3,1),bias(3,1)]);

return